# Installation

To install *spotter* from pypi
    
```bash
pip install starspotter
```

```{danger}
`starspotter` not `spotter` ! Because the name wasn't available...
```

As *spotter* is still under development, we recommend installing the latest version from the GitHub repository. To do so, clone the repository and install the package using pip:

```bash
git clone https://github.com/lgrcia/spotter
pip install -e spotter
```